# This file was auto-generated by Fern from our API Definition.

import typing
from .conditional_tool_rule import ConditionalToolRule
from .child_tool_rule import ChildToolRule
from .continue_tool_rule import ContinueToolRule
from .terminal_tool_rule import TerminalToolRule
from .max_count_per_step_tool_rule import MaxCountPerStepToolRule
from .parent_tool_rule import ParentToolRule
from .required_before_exit_tool_rule import RequiredBeforeExitToolRule
from .init_tool_rule import InitToolRule

AgentStateToolRulesItem = typing.Union[
    ConditionalToolRule,
    ChildToolRule,
    ContinueToolRule,
    TerminalToolRule,
    MaxCountPerStepToolRule,
    ParentToolRule,
    RequiredBeforeExitToolRule,
    InitToolRule,
]
