# This file was auto-generated by Fern from our API Definition.

import typing

MessageType = typing.Union[
    typing.Literal[
        "system_message",
        "user_message",
        "assistant_message",
        "reasoning_message",
        "hidden_reasoning_message",
        "tool_call_message",
        "tool_return_message",
    ],
    typing.Any,
]
